Index: includes/admin/converters/Example.php
--- includes/admin/converters/Example.php Base (BASE)
+++ includes/admin/converters/Example.php Locally Modified (Based On LOCAL)
@@ -312,7 +312,7 @@
 	/**
 	 * This method is to save the salt and password together.  That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row )
 	{
Index: includes/admin/converters/Invision.php
--- includes/admin/converters/Invision.php Base (BASE)
+++ includes/admin/converters/Invision.php Locally Modified (Based On LOCAL)
@@ -506,7 +506,7 @@
 	/**
 	 * This method is to save the salt and password together.  That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		return array( 'hash' => $field, 'salt' => $row['members_pass_salt'] );
Index: includes/admin/converters/Mingle.php
--- includes/admin/converters/Mingle.php Base (BASE)
+++ includes/admin/converters/Mingle.php Locally Modified (Based On LOCAL)
@@ -406,7 +406,7 @@
 	/**
 	 * This method is to save the salt and password together. That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		return false;
Index: includes/admin/converters/SimplePress5.php
--- includes/admin/converters/SimplePress5.php Base (BASE)
+++ includes/admin/converters/SimplePress5.php Locally Modified (Based On LOCAL)
@@ -440,7 +440,7 @@
 	/**
 	 * This method is to save the salt and password together. That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		return false;
Index: includes/admin/converters/Vanilla.php
--- includes/admin/converters/Vanilla.php Base (BASE)
+++ includes/admin/converters/Vanilla.php Locally Modified (Based On LOCAL)
@@ -518,7 +518,7 @@
 	/**
 	 * This method is to save the salt and password together. That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		return false;
Index: includes/admin/converters/bbPress1.php
--- includes/admin/converters/bbPress1.php Base (BASE)
+++ includes/admin/converters/bbPress1.php Locally Modified (Based On LOCAL)
@@ -545,7 +545,7 @@
 	/**
 	 * This method is to save the salt and password together. That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		return false;
Index: includes/admin/converters/vBulletin.php
--- includes/admin/converters/vBulletin.php Base (BASE)
+++ includes/admin/converters/vBulletin.php Locally Modified (Based On LOCAL)
@@ -494,7 +494,7 @@
 	/**
 	 * This method is to save the salt and password together.  That
 	 * way when we authenticate it we can get it out of the database
-	 * as one value. Array values are auto sanitized by wordpress.
+	 * as one value. Array values are auto sanitized by WordPress.
 	 */
 	public function callback_savepass( $field, $row ) {
 		$pass_array = array( 'hash'	 => $field, 'salt'	 => $row['salt'] );

Index: includes/admin/converter.php
--- includes/admin/converter.php Base (BASE)
+++ includes/admin/converter.php Locally Modified (Based On LOCAL)
@@ -383,7 +383,7 @@
 						}
 					} else {
 						update_option( '_bbp_converter_start', $max + 1 );
-						$this->converter_output( sprintf( __( 'Delete users wordpress default passwords (%1$s - %2$s)', 'bbpress' ), $min, $max ) );
+						$this->converter_output( sprintf( __( 'Delete users WordPress default passwords (%1$s - %2$s)', 'bbpress' ), $min, $max ) );
 					}
 				} else {
 					update_option( '_bbp_converter_step',  $step + 1 );
@@ -529,7 +529,7 @@
 	protected $field_map = array();
 
 	/**
 	 * @var object This is the connection to the wordpress datbase.
 	 */
 	protected $wpdb;
 
@@ -529,7 +529,7 @@
 
 	/**
-	 * @var object This is the connection to the wordpress datbase.
+	 * @var object This is the connection to the WordPress datbase.
 	 */
 	protected $wpdb;